import matplotlib.pyplot as plt
from memcached_conn_scan import collect_data
import os
from config import markers, colors

def plot(threads, include_caladan = False):
    data = collect_data(threads, include_caladan)

    plt.cla()
    if include_caladan:
        plt.title('Memcached connections vs LLC misses, %d threads, with Caladan' % (threads,))
    else:
        plt.title('Memcached connections vs LLC misses, %d threads' % (threads,))

    for k in data:
        plt.errorbar(data[k][0], data[k][3], yerr=data[k][4], capsize = 4, label = k, marker = markers[k], color = colors[k])

    plt.xlabel('Connections (per client w/ 7 * 8 clients)')
    plt.ylabel('LLC misses per request')

    plt.legend()
    if os.getenv('SAVE_FIGURE') != 'true':
        plt.rcParams.update({'font.size': 16})
        plt.show()
    else:
        if include_caladan:
            plt.savefig('../data/figs/memcached_conn_scan.llc_misses.t%d.caladan.png' % (threads,), dpi = 192)
        else:
            plt.savefig('../data/figs/memcached_conn_scan.llc_misses.t%d.png' % (threads,), dpi = 192)

plot(1)
plot(1, True)
plot(8)
plot(8, True)
